Enum BinMethod
pub enum BinMethod {
Intervals {
spec: DslIntervalSpec,
right_closed: bool,
},
Quantiles {
spec: FractionSpec,
right_closed: bool,
},
Ranks {
spec: FractionSpec,
},
}Variants
Intervals
Bins delimited by values.
Quantiles
Bins delimited by quantiles of the input, keeps equal values in a single bin.
Ranks
Bins delimited by position in sorted order, equal values split across bins.
Fields

spec: FractionSpecImplementations