Enum DslIntervalSpec
pub enum DslIntervalSpec {
Breaks(Series),
Count(NonZero<usize>),
}Expand description
How interval binning delimits its bins, as the caller specified it.
The breakpoints are in whichever dtype they arrived in. We can not enforce ordering here, e.g. because we would need to cast strings to Enum/Categorical.
Variants
Implementations
impl DslIntervalSpec
impl DslIntervalSpec
pub fn from_breaks(breaks: Series) -> DslIntervalSpec
pub fn from_count(count: usize) -> Result<DslIntervalSpec, PolarsError>